package com.gmscheduler.model;

/**
 * A <code>Timeframe</code> object represents a day and time range (start time and stop time). The time
 * frame is used to represent a chunk of time.
 * 
 * @author Peter Deschere
 * @version 1.0
 */
public class Timeframe {
	//class constructor
	public Timeframe(String day, String starttime, String endtime) {
		this.day = new String(day);
		this.starttime = new String(starttime);
		this.endtime = new String(endtime);
	}
	
	//class constructor
	public Timeframe(String day, Double starttime, Double endtime) {
		this.day = new String(day);
		this.starttime = toString(starttime);
		this.endtime = toString(endtime);		
	}
	
	//copy constructor
	public Timeframe(Timeframe u) {
		day = new String(u.getDay());
		starttime = new String(u.getStart());
		endtime = new String(u.getEnd());
	}
	
	//default constructor
	public Timeframe() {
		day = null;
		starttime = null;
		endtime = null;
	}

	/**
	 * Returns the day.
	 * 
	 * @return the day of the <code>Timeframe</code>
	 */
	public String getDay() {
		return day;
	}

	/**
	 * Returns the start time.
	 * 
	 * @return the start time of the <code>Timeframe</code>
	 */
	public String getStart() {
		return starttime;
	}

	/**
	 * Returns the end.
	 * 
	 * @return the end of the <code>Timeframe</code>
	 */
	public String getEnd() {
		return endtime;
	}
	
	/**
	 * Sets the Day.
	 * 
	 * @param day the new day
	 */
	public void setDay(String day) {
		this.day = new String(day);
	}
	
	/**
	 * Sets the start time.
	 * 
	 * @param starttime the new start
	 */
	public void setStart(String starttime) {
		this.starttime = new String(starttime);
	}
	
	/**
	 * Sets the end time.
	 * 
	 * @param endtime the new end
	 */
	public void setEnd(String endtime) {
		this.endtime = new String(endtime);
	}

	public String toStringMilitary() {
		if (day==null || starttime==null || endtime == null) {
			return "";
			} else {
			return day + " " + starttime + "-" + endtime;
			}
	}
	
	
	public String toString() {
		Integer x = 0;
		Integer y = 0;
		String s = "";
		String t = "";
		
		if (day==null || starttime==null || endtime == null) {
			return "";
			} else {
			x = new Integer(starttime.substring(0,starttime.indexOf(":")));
			y = new Integer(endtime.substring(0,endtime.indexOf(":")));
			if (x > 12) {
				x = x-12;
				s = "PM";
			} else {
				s = "AM";
			}
				
			if (y > 12) {
				y = y-12;
				t = "PM";
			} else {
				t = "AM";
			}

			
			return day + " " + x.toString() + starttime.substring(starttime.indexOf(":")) + s +
				   "-" + y.toString() + endtime.substring(endtime.indexOf(":")) + t;
			}
	}
		
	/**
	 * Returns the start.
	 * 
	 * @return the start of the <code>Timeframe</code> as a <code>Double</code>
	 */
	public Double getStartDouble() {
		return this.toDouble(this.getStart());
	}
	
	/**
	 * Returns the end.
	 * 
	 * @return the end of the <code>Timeframe</code> as a <code>Double</code>
	 */
	public Double getEndDouble() {
		return this.toDouble(this.getEnd());
	}
	
	/**
	 * Converts a military time string into decimal hours.
	 * 
	 * @param time a string (format ##:##) in military time
	 * @return the time in decimal hours (ex: 12:15 returns 12.25)
	 */
	private Double toDouble(String time) {
		return new Double(time.substring(0,time.indexOf(":"))) + 
			new Double(time.substring(time.indexOf(":")+1))/60;
	}
	
	/**
	 * Converts a military time string into decimal hours.
	 * 
	 * @param time a Double representation of military time
	 * @return the time in string format (ex: 12.25 returns 12:15)
	 */
	public String toString(Double time) {
		return new Integer(time.intValue()).toString() + ":" + this.toStringMinutes(time);
	}
	
	/**
	 * Converts a decimal hours into just its minutes value.
	 * 
	 * @param time a Double representation of military time
	 * @return the time in string format (ex: 12.25 returns 15)
	 */
	private String toStringMinutes(Double time) {
		return new Integer(new Double((time - time.intValue())*60).intValue()).toString();
	}
	
	/**
	 * The day of week
	 */
	private String day;
	/**
	 * The start time of the interval
	 */
	private String starttime;
	/**
	 * The end time of the interval
	 */
	private String endtime;
}
